﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Reflection;
using System.Text;
using Xamarin.Forms;
using Xamarin.Forms.Internals;

namespace SfTreeViewSamples
{
    [Preserve(AllMembers = true)]
    public class ViewModel
    {
        public ObservableCollection<SubFolder> FoldersInfo { get; set; }
        public ViewModel()
        {
                GetFiles();
        }

        private ObservableCollection<SubFolder> GetFiles()
        {
            FoldersInfo = new ObservableCollection<SubFolder>();
            Assembly assembly = typeof(MainPage).GetTypeInfo().Assembly;

            #region BoundModeCheckBoxHierarchy
            var doc = new SubFolder() { FileName = "Documents", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_folder.png", assembly) };
            var download = new SubFolder() { FileName = "Downloads", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_folder.png", assembly) };
            var mp3 = new SubFolder() { FileName = "Music", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_folder.png", assembly) };
            var picture = new SubFolder() { FileName = "Pictures", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_folder.png", assembly) };
            var video = new SubFolder() { FileName = "Videos", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_folder.png", assembly) };
  
            var pollution = new File() { FileName = "Environmental Pollution.docx", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_word.png", assembly) };
            var globalWarming = new File() { FileName = "Global Warming.ppt", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_ppt.png", assembly) };

            var game = new File() { FileName = "Game.exe", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_exe.png", assembly) };
            var tutorial = new File() { FileName = "Tutorials.zip", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_zip.png", assembly) };
            var typeScript = new File() { FileName = "TypeScript.7z", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_zip.png", assembly) };
            var uiGuide = new File() { FileName = "UI-Guide.pdf", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_pdf.png", assembly) };

            var song = new File() { FileName = "Gouttes", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_folder.png", assembly) };

            var camera = new File() { FileName = "Camera Roll", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_folder.png", assembly) };
            var stone = new File() { FileName = "Stone.jpg", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_png.png", assembly) };
            var wind = new File() { FileName = "Wind.jpg", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_png.png", assembly) };

            var video1 = new File() { FileName = "Naturals.mp4", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_video.png", assembly) };
            var video2 = new File() { FileName = "Wild.mpeg", ImageIcon = ImageSource.FromResource("SfTreeViewSamples.Icons.treeview_video.png", assembly) };

            doc.Files = new ObservableCollection<File>
            {
                pollution,
                globalWarming
            };

            download.Files = new ObservableCollection<File>
            {
                game,
                tutorial,
                typeScript,
                uiGuide,
                camera
            };

            mp3.Files = new ObservableCollection<File>
            {
                song
            };

            picture.Files = new ObservableCollection<File>
            {
                camera,
                stone,
                wind
            };

            video.Files = new ObservableCollection<File>
            {
                camera,
                video1,
                video2
            };

            FoldersInfo.Add(doc);
            FoldersInfo.Add(download);
            FoldersInfo.Add(mp3);
            FoldersInfo.Add(picture);
            FoldersInfo.Add(video);
            #endregion

            return FoldersInfo;

        }
    }

    #region BoundModeCheckBox
    [Preserve(AllMembers = true)]
    public class SubFolder : INotifyPropertyChanged
    {
        #region Fields

        private string fileName;
        private ImageSource imageIcon;
        private ObservableCollection<File> files;

        #endregion

        #region Constructor
        public SubFolder()
        {
        }

        #endregion

        #region Properties
        public ObservableCollection<File> Files
        {
            get { return files; }
            set
            {
                files = value;
                RaisedOnPropertyChanged("Files");
            }
        }

        public string FileName
        {
            get { return fileName; }
            set
            {
                fileName = value;
                RaisedOnPropertyChanged("FileName");
            }
        }
        public ImageSource ImageIcon
        {
            get { return imageIcon; }
            set
            {
                imageIcon = value;
                RaisedOnPropertyChanged("ImageIcon");
            }
        }

        #endregion

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        public void RaisedOnPropertyChanged(string _PropertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(_PropertyName));
            }
        }

        #endregion
    }

    [Preserve(AllMembers = true)]
    public class File : INotifyPropertyChanged
    {
        #region Fields

        private string fileName;
        private ImageSource imageIcon;

        #endregion

        #region Constructor
        public File()
        {
        }

        #endregion

        #region Properties

        public string FileName
        {
            get { return fileName; }
            set
            {
                fileName = value;
                RaisedOnPropertyChanged("FileName");
            }
        }
        public ImageSource ImageIcon
        {
            get { return imageIcon; }
            set
            {
                imageIcon = value;
                RaisedOnPropertyChanged("ImageIcon");
            }
        }

        #endregion

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        public void RaisedOnPropertyChanged(string _PropertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(_PropertyName));
            }
        }

        #endregion
    }
    #endregion
}